==> trade-center-api-2.4.15-20220303.073733-10-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteOrderItemService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.order.center.api.dto.OrderItemDto;
import com.alibaba.fastjson.JSONObject;

import java.util.List;

/**
 * @author JunAngLiu
 * @Title: RemoteOrderItemService
 * @Description:
 * @date 2018/7/413:57
 */
@AdvancedFeignClient
public interface RemoteOrderItemService {

    /**
     * 根据 主订单id查询 子订单
     * @link  queryItemListByOderId
     * */
    @Deprecated
     List<OrderItemDto> queryByOderId(Long OrderId) throws BizException;

    /**
     * 根据 主订单id集合 批量 查询 子订单
     * @link  queryItemListByOrderIds
     * */
    @Deprecated
    List<OrderItemDto>queryByOrderIds(List<Long> orderIds,Long consumerId) throws BizException;


    /**
     * 根据 主订单id查询 子订单
     * */
    List<OrderItemDto> findByOrderIds(List<Long> orderIds);


    /**
     * 更新优惠券ID
     * @param orderId
     * @param consumerId
     * @param couponId
     * @return
     */
    Boolean updateCouponId(Long orderId, Long consumerId, Long couponId);

    /**
     * 更新子订单状态
     * 注意：如果ordersItemId子订单号不传，会更新主订单下面的所有子订单状态
     * @param orderId
     * @param consumerId
     * @param ordersItemId
     * @param status
     * @return
     */
    Boolean updateStatus(Long orderId,Long consumerId, Long ordersItemId, Integer status);

    /**
     * 批量取消发货
     * @param orderId
     * @param consumerId
     * @param ordersItemIds
     * @throws BizException
     */
    void batchCancelOrderItem(Long orderId,Long consumerId, List<Long> ordersItemIds,String error4admin,String error4developer,String error4consumer) throws BizException;

    /**
     * 批量发货
     * @param orderId
     * @param consumerId
     * @param ordersItemIds
     * @throws BizException
     */
    void batchSendOrderItem(Long orderId,Long consumerId, List<Long> ordersItemIds) throws BizException;

    void batchReceiveOrderItem(Long orderId,Long consumerId) throws BizException;

    List<Long> queryOrderItemIdByOrderId(Long orderId);

    /**
     * 根据itemId查询商品
     * @param itemId
     * @return
     */
    OrderItemDto queryByItemId(Long itemId);

    /**
     * 根据 主订单id查询 子订单
     * */
    List<OrderItemDto> queryItemListByOderId(Long orderId) ;

    /**
     * 根据 主订单id集合 批量 查询 子订单
     * */
    List<OrderItemDto>queryItemListByOrderIds(List<Long> orderIds,Long consumerId);



    /**
     * 仅试用新订单号 17年中旬以后（以订单号后4位进行分表的方式）
     * 仅根据 订单id集合 批量查询 ，特殊需求 才使用该接口
     * */
    List<OrderItemDto> findByIdsAndSuffix(List<Long> orderIds, String tableSuffix);

    /**
     * 根据主订单和子订单列表查询详情
     * @param orderId
     * @param ordersItemIdList
     * @return
     */
    List<OrderItemDto> queryByOrdersItemId(Long orderId, List<Long> ordersItemIdList);

    /**
     * 修改子订单业务参数，json格式
     * @param orderId
     * @param orderItemId
     * @param jsonObject
     * @return
     */
    Boolean updateOrderItemBizParam(Long orderId, Long orderItemId, JSONObject jsonObject);

    /**
     * 修改子订单回滚积分状态
     * @param orderId
     * @param consumerId
     * @param ordersItemIds
     * @param status
     * @return
     */
    Boolean updateConsumerPayStatusByCredits(Long orderId, Long consumerId, List<Long> ordersItemIds, String status);
}

==> trade-center-api-2.4.15-20220315.025912-29-sources.jar: cn/com/duiba/order/center/api/remoteservice/RemoteOrderItemService.java <==
package cn.com.duiba.order.center.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.order.center.api.dto.OrderItemDto;
import com.alibaba.fastjson.JSONObject;

import java.util.List;
import java.util.Map;

/**
 * @author JunAngLiu
 * @Title: RemoteOrderItemService
 * @Description:
 * @date 2018/7/413:57
 */
@AdvancedFeignClient
public interface RemoteOrderItemService {

    /**
     * 根据 主订单id查询 子订单
     * @link  queryItemListByOderId
     * */
    @Deprecated
     List<OrderItemDto> queryByOderId(Long OrderId) throws BizException;

    /**
     * 根据 主订单id集合 批量 查询 子订单
     * @link  queryItemListByOrderIds
     * */
    @Deprecated
    List<OrderItemDto>queryByOrderIds(List<Long> orderIds,Long consumerId) throws BizException;


    /**
     * 根据 主订单id查询 子订单
     * */
    List<OrderItemDto> findByOrderIds(List<Long> orderIds);


    /**
     * 更新优惠券ID
     * @param orderId
     * @param consumerId
     * @param couponId
     * @return
     */
    Boolean updateCouponId(Long orderId, Long consumerId, Long couponId);

    /**
     * 更新子订单状态
     * 注意：如果ordersItemId子订单号不传，会更新主订单下面的所有子订单状态
     * @param orderId
     * @param consumerId
     * @param ordersItemId
     * @param status
     * @return
     */
    Boolean updateStatus(Long orderId,Long consumerId, Long ordersItemId, Integer status);

    /**
     * 批量取消发货
     * @param orderId
     * @param consumerId
     * @param ordersItemIds
     * @throws BizException
     */
    void batchCancelOrderItem(Long orderId,Long consumerId, List<Long> ordersItemIds,String error4admin,String error4developer,String error4consumer) throws BizException;

    /**
     * 批量发货
     * @param orderId
     * @param consumerId
     * @param ordersItemIds
     * @throws BizException
     */
    void batchSendOrderItem(Long orderId,Long consumerId, List<Long> ordersItemIds) throws BizException;

    void batchReceiveOrderItem(Long orderId,Long consumerId) throws BizException;

    List<Long> queryOrderItemIdByOrderId(Long orderId);

    /**
     * 根据itemId查询商品
     * @param itemId
     * @return
     */
    OrderItemDto queryByItemId(Long itemId);

    /**
     * 根据子订单号查询子订单信息
     * @param orderItemId
     * @return
     */
    OrderItemDto queryByOrderItemId(Long orderItemId) throws BizException;

    /**
     * 根据订单号和子订单号查询
     * @param orderId
     * @param orderItemId
     * @return
     * @throws BizException
     */
    OrderItemDto queryByOrderIdAndOrdersItemId(Long orderId, Long orderItemId) throws BizException;

    /**
     * 根据 主订单id查询 子订单
     * */
    List<OrderItemDto> queryItemListByOderId(Long orderId) ;

    /**
     * 根据 主订单id集合 批量 查询 子订单
     * */
    List<OrderItemDto>queryItemListByOrderIds(List<Long> orderIds,Long consumerId);



    /**
     * 仅试用新订单号 17年中旬以后（以订单号后4位进行分表的方式）
     * 仅根据 订单id集合 批量查询 ，特殊需求 才使用该接口
     * */
    List<OrderItemDto> findByIdsAndSuffix(List<Long> orderIds, String tableSuffix);

    /**
     * 根据主订单和子订单列表查询详情
     * @param orderId
     * @param ordersItemIdList
     * @return
     */
    List<OrderItemDto> queryByOrdersItemId(Long orderId, List<Long> ordersItemIdList);

    /**
     * 修改子订单业务参数，json格式
     * @param orderId
     * @param orderItemId
     * @param jsonObject
     * @return
     */
    @Deprecated
    Boolean updateOrderItemBizParam(Long orderId, Long orderItemId, JSONObject jsonObject);

    /**
     * 修改子订单业务参数
     * @param orderId
     * @param orderItemId
     * @param params
     * @return
     */
    Boolean batchUpdateOrderItemBizParam(Long orderId, Long orderItemId, Map<String,Object> params);

    /**
     * 修改子订单回滚积分状态
     * @param orderId
     * @param consumerId
     * @param ordersItemIds
     * @param status
     * @return
     */
    Boolean updateConsumerPayStatusByCredits(Long orderId, Long consumerId, List<Long> ordersItemIds, String status);
}
